@@ -2,6 +2,7 @@ import random
 import hashlib
 import datetime
 from django.db import models
+from django.utils import timezone
 from django.contrib.auth.models import User
 
 Q = models.Q
@@ -24,7 +25,7 @@ class CallbackMapManager(models.Manager):
         return self.get_query_set().filter(query)
 
     def all_expired_callbacks(self, days=7, delete_errors=False):
-        use_date = datetime.date.today() - datetime.timedelta(days=days)
+        use_date = timezone.now().date() - datetime.timedelta(days=days)
         query = Q(is_active=False) 
         if not delete_errors:
             query &= Q(is_error=False)
